@@ -29,7 +29,7 @@ package cPanel::PublicAPI;
 # OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-our $VERSION = '2.2';
+our $VERSION = '2.3';
 
 use strict;
 use Carp            ();
@@ -614,7 +614,7 @@ sub _init {
 
     # moved this over to a pattern to allow easy change of deps
     foreach my $encoder (
-        [ 'Cpanel/CPAN/URI/Escape.pm', \&Cpanel::CPAN::URI::Escape::uri_escape ],
+        [ 'Cpanel/Encoder/URI.pm', \&Cpanel::Encoder::URI::uri_encode_str ],
         [ 'URI/Escape.pm',             \&URI::Escape::uri_escape ],
       ) {
         my $module   = $encoder->[0];
